Description Usage Arguments Value
The growth rate or entropy of the Kelly strategy
The average log wealth at the optimal strategy.
1 | entropy_binary(a, b, p)
|
a |
the amount won on top of the wager |
b |
the wager lost |
p |
the probability of winning |
numeric
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.